# Centralized style definitions for the application

SECTION_HEADER_STYLE = "font-weight: bold; font-size: 12pt; margin-top: 10px;"
BUTTON_SUCCESS_STYLE = "background-color: #4CAF50; color: white;"
BUTTON_ERROR_STYLE = "background-color: #F44336; color: white;"
BUTTON_INFO_STYLE = "background-color: #2196F3; color: white;"
