# Centralized constants and style definitions

APP_TITLE = "Licensing Specialist"

# Colors
COLOR_SUCCESS = "#4CAF50"
COLOR_ERROR = "#F44336"
COLOR_INFO = "#2196F3"

# Styles
STYLE_SECTION_HEADER = "font-weight: bold; font-size: 12pt; margin-top: 10px;"

# Strings
LABEL_NAME = "Name"
LABEL_EMAIL = "Email"
LABEL_PHONE = "Phone"
LABEL_REP_CODE = "Rep code"
LABEL_APPLICATION_DATE = "Application date"
LABEL_APPROVAL_DATE = "Approval date"
LABEL_LICENSE_NUMBER = "License number"
LABEL_STATUS = "Status"
